@@ -17,14 +17,16 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#if defined(ATK_DISABLE_SINGLE_INCLUDES) && !defined (__ATK_H_INSIDE__) && !defined (ATK_COMPILATION)
+#error "Only <atk/atk.h> can be included directly."
+#endif
+
 #ifndef __ATK_VALUE_H__
 #define __ATK_VALUE_H__
 
 #include <atk/atkobject.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 /*
  * The AtkValue interface should be supported by any object that 
@@ -57,9 +59,9 @@ struct _AtkValueIface
                                   GValue       *value);
   gboolean (* set_current_value) (AtkValue     *obj,
                                   const GValue *value);
-
+  void     (* get_minimum_increment) (AtkValue   *obj,
+				      GValue     *value);
   AtkFunction pad1;
-  AtkFunction pad2;
 };
 
 GType            atk_value_get_type (void);
@@ -77,16 +79,15 @@ void     atk_value_get_minimum_value  (AtkValue     *obj,
 gboolean atk_value_set_current_value  (AtkValue     *obj,
                                        const GValue *value);
 
+void     atk_value_get_minimum_increment  (AtkValue     *obj,
+					   GValue       *value);
+
 /*
  * Additional GObject properties exported by GaccessibleValue:
  *    "accessible_value"
  *       (the accessible value has changed)
  */
 
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
-
+G_END_DECLS
 
 #endif /* __ATK_VALUE_H__ */
